``bar_label`` supports individual padding per label
---------------------------------------------------
``bar_label`` will now accept both a float value or an array-like for
padding. The array-like defines the padding for each label individually.
